#
# spec file for package opensm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         git_ver .0.844ab3b7edaa
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define lib_osm_major 9
%define lib_osmcomp_major 5
%define lib_osmvendor_major 5

Name:           opensm
Summary:        Infiniband Subnet Manager
License:        BSD-2-Clause OR GPL-2.0-only
Group:          Productivity/Networking/System
Version:        3.3.24
Release:        3.8
Source:         opensm-%{version}%{git_ver}.tar.gz
Source1:        conf.sysconfig
Source2:        %{name}.launch
Source3:        opensm.service
Source4:        baselibs.conf
Patch1:         opensm-remove-date-time.patch
URL:            https://github.com/linux-rdma/opensm
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libibumad-devel
BuildRequires:  libtool
BuildRequires:  systemd-rpm-macros
PreReq:         %fillup_prereq
Requires:       logrotate
%{?systemd_requires}

%description
OpenSM provides an implementation for an InfiniBand Subnet Manager and
Administration. Such a software entity is required to run for in order
to initialize the InfiniBand hardware (at least one per each InfiniBand
subnet).

%package -n libopensm%{lib_osm_major}
Summary:        Opensm runtime library
Group:          System/Libraries
Obsoletes:      opensm-libs3

%description -n libopensm%{lib_osm_major}
This package contains one of the opensm runtime libraries.

%package -n libosmcomp%{lib_osmcomp_major}
Summary:        Opensm runtime library
Group:          System/Libraries
Obsoletes:      opensm-libs3

%description -n libosmcomp%{lib_osmcomp_major}
This package contains one of the opensm runtime libraries.

%package -n libosmvendor%{lib_osmvendor_major}
Summary:        Opensm runtime library
Group:          System/Libraries
Obsoletes:      opensm-libs3

%description -n libosmvendor%{lib_osmvendor_major}
This package contains one of the opensm runtime libraries.

%package        devel
Summary:        Development files for OpenSM
Group:          Development/Libraries/C and C++
Requires:       libibumad-devel
Requires:       libopensm%{lib_osm_major} = %{version}
Requires:       libosmcomp%{lib_osmcomp_major} = %{version}
Requires:       libosmvendor%{lib_osmvendor_major} = %{version}

%description devel
Symlinks for the dynamic libraries and header files for OpenSM.

%prep
%setup -q -n  %{name}-%{version}%{git_ver}
%patch1

cp %{S:1} %{S:2} %{S:3} .
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" opensm/osm_console.c

%build
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags} V=1

%install
export NO_BRP_STALE_LINK_ERROR=yes
make DESTDIR=%{buildroot} install
install -D -m 644 scripts/opensm.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/opensm

# get rid of the included init script because we use a systemd unit file instead
rm -rf %{buildroot}%_sysconfdir/init.d/
install -Dm 644 %{SOURCE3} %{buildroot}%_unitdir/%{name}.service
sed -i -e 's$@LIBEXEC@$%{_libexecdir}$g' %{buildroot}%_unitdir/%{name}.service
install -D %{SOURCE2}  %{buildroot}%{_libexecdir}/opensm-launch
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}

# install the sysconfig configuration file
install -m 644 -D conf.sysconfig %{buildroot}%{_fillupdir}/sysconfig.%name

# and make a compat link
ln -s %_sysconfdir/sysconfig/opensm %{buildroot}/%_sysconfdir/opensm.conf
sed -i -e 's$-L/usr/src/packages/BUILD/%{name}-%{version}/complib$$g' %{buildroot}%{_libdir}/libosmvendor.la

#we don't package static libraries anymore.
rm -f %{buildroot}%_libdir/lib{opensm,osmcomp,osmvendor}.la

%pre
%service_add_pre opensm.service

%post
%{fillup_only}
%service_add_post opensm.service

%preun
%service_del_preun opensm.service

%postun
%service_del_postun opensm.service

%post   -n libopensm%{lib_osm_major} -p /sbin/ldconfig
%postun -n libopensm%{lib_osm_major} -p /sbin/ldconfig
%post   -n libosmcomp%{lib_osmcomp_major} -p /sbin/ldconfig
%postun -n libosmcomp%{lib_osmcomp_major} -p /sbin/ldconfig
%post   -n libosmvendor%{lib_osmvendor_major} -p /sbin/ldconfig
%postun -n libosmvendor%{lib_osmvendor_major} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%_sysconfdir/opensm.conf
%doc COPYING
%_unitdir/opensm.service
%config %_sysconfdir/logrotate.d/opensm
%_sbindir/*
%{_libexecdir}/opensm-launch
%_mandir/man5/torus-2QoS.conf.5.gz
%_mandir/man8/torus-2QoS.8.gz
%_mandir/man8/opensm.8.gz
%_mandir/man8/osmtest.8.gz
%{_fillupdir}/sysconfig.%name

%files -n libopensm%{lib_osm_major}
%defattr(-, root, root)
%_libdir/libopensm.so.%{lib_osm_major}*

%files -n libosmcomp%{lib_osmcomp_major}
%defattr(-,root,root)
%_libdir/libosmcomp.so.%{lib_osmcomp_major}*

%files -n libosmvendor%{lib_osmvendor_major}
%defattr(-,root,root)
%_libdir/libosmvendor.so.%{lib_osmvendor_major}*

%files devel
%defattr(-,root,root)
%_includedir/infiniband/complib/
%_includedir/infiniband/iba/
%_includedir/infiniband/opensm/
%_includedir/infiniband/vendor/
%_libdir/libopensm.so
%_libdir/libosmcomp.so
%_libdir/libosmvendor.so

%changelog
* Tue Jan 11 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update opensm sysconfig defaults to match current launch script
  Most options have been removed as they should be configured in the opensm.conf file
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * opensm.service
* Tue Aug 24 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 3.3.24 (jsc#SLE-19252)
  - Support for NDR link speed
  - Backward compatibility for old drivers
  - Several bug fixes
* Wed Nov  4 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Support any value for %%{_libexecdir} (bsc#1178326)
* Fri Mar 20 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 3.3.23
  - Add support for registering an opensm plugin as a new routing engine
  - Internal improvements and bug fixes
* Thu Apr 18 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 3.3.22
  - Internal library reorganization to remove circular dependencies
  - Added a few additional command line options which were supported by options to be consistent with RedHat Fedora startup script
  - Internal improvements and bug fixes
- Remove unneeded build dependencies
* Mon Sep 24 2018 nmoreychaisemartin@suse.com
- Update to version 3.3.21 (fate#326015)
  * Support for HDR links and 2x link width
  * Nue routing algorithm
  * Support for ignoring throttled links with DFSSSP
  * Support for long transaction timout for SM class transactions
  * Many bug fixes
- Drop opensm-type_punning.patch as it was fixed upstream
* Fri Jun 15 2018 nmoreychaisemartin@suse.com
- Update Source and URL as opensm was moved to GitHub
- Add a _service file to be able to auto-fetch from github
* Wed Jan  3 2018 nmoreychaisemartin@suse.com
- Update opensm.service to use the new rdma-core
  systemd target (bsc#1074439)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Jun 23 2017 nmoreychaisemartin@suse.com
- Have new libs packages obsolete the old opensm-libs3
* Mon Jun 19 2017 jengelh@inai.de
- Implement shared library packaging guideline
- Rectify opensm-type_punning.patch:
  a union does not fix type punning problems (let alone
  misalignmened pointers), one must use memcpy.
* Mon Jun 12 2017 nmoreychaisemartin@suse.com
- Backport changes from SLE12-SP3 (bsc#1041403)
- Add opensm-remove-date-time.patch to remove __DATE__ and
  __TIME__ from build
- Rename /usr/sbin/rcopensmd to /usr/sbin/rcopensm to match binary
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Update to version 3.3.20
  * No concise list of changes present so see the file ChangeLog in
    the package documentation directory.
- Update opensm-type_punning.patch to new sources
* Mon Mar 21 2016 pth@suse.de
- Drop opensm-autotools.patch as the fix is in.
- Refresh opensm-type_punning.patch to match changed sources.
* Fri Mar 11 2016 pth@suse.de
- Update to 3.3.19 git version (bsc#970668)
  Changes to numerous to be listed here so please see
  ChangeLog for the changes since 3.3.17.
* Sun Mar  8 2015 p.drouand@gmail.com
- Update to version 3.3.19
  * No concise list of changes present so see the file ChangeLog in
    the package documentation directory.
- Move to systemd
  * Replace opensmd with opensm.service
  * Replace sldd.sh with opensm.launch
  * Add systemd-rpm-macros and %%{?systemd_requires} require
  * Replace sysvinit post/postun macros with systemd one
- Use download Url as source
- Get rid of some extra stuff
* Tue Aug 26 2014 fcrozat@suse.com
- Add obsoletes/provides to baselibs.conf.
* Tue Aug 12 2014 pth@suse.de
- Fix the Processname stated in a comment (bnc#884648).
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Tue Apr 22 2014 pth@suse.de
- Build for s390.
* Thu Feb 13 2014 pth@suse.de
- Update to 3.3.17 for fate#315488. No concise list of changes
  present so see the file ChangeLog in the package documentation
  directory.
* Mon Feb 10 2014 pth@suse.de
- Fix license, include COPYING.
- Fix baselibs.conf.
* Fri Jan 31 2014 pth@suse.de
- Only ppc64le is supported so remove everything that triggered
  on ppc or ppc64.
- Remove opensm-no_g0_when_daemon.patch as the fix has been
  integrated.
* Fri Jan 24 2014 pth@suse.de
- Remove old tarball.
* Mon Jan 20 2014 pth@suse.de
- Update to 3.3.16 from OFED 3.12.
- Use spdx.org format for license specification.
- fix type-punning by using unions: opensm-type_punning.patch.
* Wed Jan 15 2014 pth@suse.de
- Use spdx.org for license specification.
* Thu Sep 13 2012 pth@suse.de
- Use sed instead of a patch to fix the use of __DATE__ and __TIME__.
* Tue Sep 11 2012 pth@suse.de
- Update to 3.3.13 from OFED 1.5.4.1
* Tue Jul  3 2012 pth@suse.de
- Update to 3.3.12 from OFED 1.5.4.
- Split off shared libraries to their own package.
- Don't use __DATE_ and __TIME__ in version output.
- Provide /usr/sbin/rcopensmd symlink.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Tue Dec 14 2010 pth@suse.de
- Fix name of libibumad devel package.
* Mon Dec 13 2010 pth@suse.de
- Split off static libraries to their own sub package.
* Wed Oct 27 2010 jjolly@novell.com
- one more dependency version for libibumad
* Wed Oct 27 2010 jjolly@novell.com
- Versioned the libibumad dependency
* Mon Oct 25 2010 jjolly@novell.com
- Update to v3.3.7 from OFED 1.5.2
- Removed Weighted Routing Patch
* Thu Dec  3 2009 jjolly@suse.de
- Corrected path in opensmd to opensm (bnc#529746)
* Thu Dec  3 2009 jjolly@suse.de
- Weighted routing patch (bnc#540371,FATE#306944)
* Thu Dec  3 2009 jjolly@suse.de
- Updated to 3.2.6_20090317 from OFED 1.4.2
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Nov 20 2008 jjolly@suse.de
- Updated to 3.2.3_20081117_b70e2d2 from OFED 1.4 rc5
  - adapted header files for OFED 1.4
* Thu Nov  6 2008 ihno@suse.de
- Adding baselibs.conf
- Adding ExcludeArch s390 s390x
* Fri Oct 24 2008 jjolly@suse.de
- Updated to version from the OFED 1.4 RC3
* Thu Sep 11 2008 jjolly@suse.de
- Update to 3.2.2 from the OFED 1.4 RC1
* Tue Mar  4 2008 jjolly@suse.de
- Update to 3.1.10 from the OFED 1.3 GA release
- Added bison and flex to the BuildRequires list
* Wed Feb 13 2008 pth@suse.de
- Remove references to $srcdir from RPATH.
- Add Short-Description to opensm init script
- Add AM_PROG_CC_C_O to configure
- Run autoreconf
- Pass [foreign] to AM_INIT_AUTOMAKE
- Update to 3.1.8:
  Number of changes far too long, see NEWS for a detailed list
* Tue Oct  2 2007 dbahi@suse.de
- Added %%preun to stop opensmd
* Mon Aug 20 2007 hvogel@suse.de
- Update to version from OFED 1.2.5
- readd the init scripts from OFED instead of the default opensm
  one
* Tue Aug  7 2007 hvogel@suse.de
- Update to version from OFED 1.2c
* Thu Jul 12 2007 hvogel@suse.de
- Install a missing script
- Install configuration as sysconfig file
- Include init script
* Wed Jul  4 2007 hvogel@suse.de
- Add GPL COPYING file [#289225]
* Tue Jul  3 2007 hvogel@suse.de
- Use 3.0.3 which is the correct version included in
  OFED 1.2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 2.2.0
